@@ -277,3 +277,33 @@ TASKS_TO_SHARE_WITH_SPOKES = [
     "SharePortfolioViaOrgsTask",
     "SharePortfolioTask",
 ]
+
+CLOUDFORMATION_HAPPY_STATUS = [
+    "CREATE_COMPLETE",
+    "UPDATE_ROLLBACK_COMPLETE",
+    "UPDATE_COMPLETE",
+    "IMPORT_COMPLETE",
+    "IMPORT_ROLLBACK_COMPLETE",
+]
+
+CLOUDFORMATION_UNHAPPY_STATUS = [
+    "CREATE_FAILED",
+    "ROLLBACK_FAILED",
+    "DELETE_FAILED",
+    "UPDATE_FAILED",
+    "UPDATE_ROLLBACK_FAILED",
+    "IMPORT_ROLLBACK_FAILED",
+]
+
+CLOUDFORMATION_IN_PROGRESS_STATUS = [
+    "CREATE_IN_PROGRESS",
+    "ROLLBACK_IN_PROGRESS",
+    "DELETE_IN_PROGRESS",
+    "UPDATE_COMPLETE_CLEANUP_IN_PROGRESS",
+    "UPDATE_IN_PROGRESS",
+    "UPDATE_ROLLBACK_IN_PROGRESS",
+    "UPDATE_ROLLBACK_COMPLETE_CLEANUP_IN_PROGRESS",
+    "REVIEW_IN_PROGRESS",
+    "IMPORT_IN_PROGRESS",
+    "IMPORT_ROLLBACK_IN_PROGRESS",
+]
